@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Server Settings Plugin
-  * Copyright (c) 2008-2009 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2008-2010 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -106,8 +106,8 @@ global $server_settings_option_pages;
 //                               how to look up the setting's value and put
 //                               a new value in its place.  The elements herein
 //                               and their possible values are defined in the
-//                               Server Settings plugin (see the Configuration
-//                               section in its README file).
+//                               Server Settings Backend plugin (see the
+//                               Configuration section in its README file).
 //
 // Note that several of the values herein will be passed through the
 // SquirrelMail translation engine before being displayed.  If you use
@@ -356,7 +356,7 @@ $server_settings_option_pages = array(
                   // We'll strip the username of its domain part, assuming
                   // the FTP server wants just the username part.
                   //
-                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
+//                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
                ),
 
                // Here is where we build the second save action where
@@ -383,7 +383,7 @@ $server_settings_option_pages = array(
                   'MAX_SEQUENTIAL_EMPTY_LINES' => 1,
                   'TREAT_AS_EMPTY_WHEN_NOT_FOUND' => array('VALUE' => 1),
                   'DELETE_WHEN_EMPTY'     => array('VALUE' => 1),
-                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
+//                  'USERNAME'              => array('STRIP_DOMAIN' => 1),
                ),
 
             ),
@@ -451,7 +451,7 @@ $server_settings_option_pages = array(
                   'DELETE_WHEN_EMPTY'    => array('VALUE' => 1),
                   'TREAT_AS_EMPTY_WHEN_NOT_FOUND' => array('VALUE' => 1),
                   'MAX_SEQUENTIAL_EMPTY_LINES' => 1,
-                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
+//                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
                ),
                array(
                   'BACKEND'               => 'ftp',
@@ -466,7 +466,7 @@ $server_settings_option_pages = array(
                   'MAX_SEQUENTIAL_EMPTY_LINES' => 1,
                   'TREAT_AS_EMPTY_WHEN_NOT_FOUND' => array('VALUE' => 1),
                   'DELETE_WHEN_EMPTY'     => array('VALUE' => 1),
-                  'USERNAME'             => array('STRIP_DOMAIN' => 1),
+//                  'USERNAME'              => array('STRIP_DOMAIN' => 1),
                ),
 
             ),
